/************************************************************************
 *   IRC - Internet Relay Chat, doc/example_module.c
 *   Copyright (C) 2001 Hybrid Development Team
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 1, or (at your option)
 *   any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *   $Id: m_buildencap.c,v 1.2 2004/02/02 23:42:24 ircd Exp $
 */

/* List of ircd includes from ../include/ */
#include "stdinc.h"
#include "handlers.h"
#include "client.h"
#include "common.h"     /* FALSE bleah */
#include "ircd.h"
#include "irc_string.h"
#include "numeric.h"
#include "fdlist.h"
#include "s_bsd.h"
#include "s_conf.h"
#include "s_log.h"
#include "s_serv.h"
#include "send.h"
#include "msg.h"
#include "parse.h"
#include "modules.h"

static void m_myencap (struct Client *, struct Client *, int, char **);

char *reconstruct_parv(int parc, char *parv[]);

struct Message myencap_msgtab = {
    "BUILDENCAP", 0, 0, 2, 0, MFLG_SLOW, 0,
    { m_unregistered, m_not_oper, m_ignore, m_myencap }
};

#ifndef STATIC_MODULES
void
_modinit(void)
{
  mod_add_cmd(&myencap_msgtab);
}

void
_moddeinit(void)
{
  mod_del_cmd(&myencap_msgtab);
}

const char *_version = "$Revision: 1.0 $";
#endif

char *reconstruct_parv(int parc, char *parv[])
{
  static char tmpbuf[BUFSIZE]; int i;

  strlcpy(tmpbuf, parv[0], BUFSIZE);
  for (i = 1; i < parc; i++)
  {
    strlcat(tmpbuf, " ", BUFSIZE);
    strlcat(tmpbuf, parv[i], BUFSIZE);
  }
  return tmpbuf;
}

static void m_myencap (struct Client *client_p, struct Client *source_p,
			int parc, char *parv[])
{
    char *tosend, command[BUFSIZE];
    strlcpy (command, parv[1], BUFSIZE);

	if (!IsAdmin(source_p))
	{
		sendto_one(source_p, ":%s NOTICE %s :You have no A flag", me.name, parv[0]);
		return;
	}

	if (parv[2] != NULL)
		tosend = reconstruct_parv (parc - 2, &parv[2]);

    sendto_server (NULL, NULL, CAP_ENCAP, NOCAPS, ":%s ENCAP * %s %s", parv[0], command, (tosend)? tosend : NULL);
}
